#
# spec file for package kate
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 6.6.0
%define plasma6_version 5.27.80
%define qt6_version 6.6.0

%bcond_without released
Name:           kate
Version:        24.12.3
Release:        1.2
Summary:        Advanced Text Editor
License:        GPL-3.0-or-later
URL:            https://kate-editor.org
Source0:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
# PATCH-FIX-OPENSUSE
Patch0:         0001-Defuse-root-block.patch
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  qt6-gui-private-devel >= %{qt6_version}
BuildRequires:  cmake(KF6CoreAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6Crash) >= %{kf6_version}
BuildRequires:  cmake(KF6DBusAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6DocTools) >= %{kf6_version}
BuildRequires:  cmake(KF6GuiAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KF6IconThemes) >= %{kf6_version}
BuildRequires:  cmake(KF6KIO) >= %{kf6_version}
BuildRequires:  cmake(KF6NewStuff) >= %{kf6_version}
BuildRequires:  cmake(KF6TextEditor) >= %{kf6_version}
BuildRequires:  cmake(KF6UserFeedback) >= %{kf6_version}
BuildRequires:  cmake(KF6Wallet) >= %{kf6_version}
BuildRequires:  cmake(KF6WindowSystem) >= %{kf6_version}
BuildRequires:  cmake(PlasmaActivities) >= %{plasma6_version}
BuildRequires:  cmake(Qt6Concurrent) >= %{qt6_version}
BuildRequires:  cmake(Qt6Keychain)
BuildRequires:  cmake(Qt6Sql) >= %{qt6_version}
BuildRequires:  cmake(Qt6Test) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
Requires:       kate-plugins = %{version}
Recommends:     kuiviewer
Recommends:     markdownpart
Recommends:     svgpart
Obsoletes:      kate5 < %{version}
Provides:       kate5 = %{version}

%description
Kate is an advanced text editor by KDE.

%package -n kwrite
Summary:        KDE Text Editor
Requires:       kate-plugins = %{version}
Obsoletes:      kwrite5 < %{version}

%description -n kwrite
KWrite is a text editor by KDE.

%package plugins
Summary:        KDE Text Editor plugins
Obsoletes:      kate5-plugins < %{version}
Provides:       ktexteditorpreviewplugin = %{version}
Obsoletes:      ktexteditorpreviewplugin < %{version}

%description plugins
Kate is an advanced text editor by KDE. This package contains
plugins and data files for Kate and KWrite editors.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf6

%kf6_build

%install
%kf6_install

# Remove exotic icon sizes
rm -r %{buildroot}%{_kf6_iconsdir}/hicolor/{150x150,310x310,44x44}

%find_lang %{name} --with-man --with-html --all-name

%ldconfig_scriptlets

%files
%doc README.md
%doc %lang(en) %{_kf6_htmldir}/en/kate/
%doc %lang(en) %{_kf6_htmldir}/en/katepart/
%doc %{_kf6_mandir}/man1/kate.1%{?ext_man}
%{_kf6_applicationsdir}/org.kde.kate.desktop
%{_kf6_appstreamdir}/org.kde.kate.appdata.xml
%{_kf6_bindir}/kate
%{_kf6_iconsdir}/hicolor/*/apps/kate.*
%{_kf6_libdir}/libkateprivate.so.*

%files -n kwrite
%doc README.md
%{_kf6_applicationsdir}/org.kde.kwrite.desktop
%{_kf6_appstreamdir}/org.kde.kwrite.appdata.xml
%{_kf6_bindir}/kwrite
%{_kf6_iconsdir}/hicolor/*/apps/kwrite.*

%files plugins
%{_kf6_plugindir}/kf6/ktexteditor/
%{_kf6_sharedir}/kateproject/
%{_kf6_sharedir}/katexmltools/

%files lang -f %{name}.lang
%exclude %{_kf6_htmldir}/en/kate/
%exclude %{_kf6_htmldir}/en/katepart/

%changelog
* Tue Mar  4 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.3/
- Changes since 24.12.2:
  * Fix not able to create branch
  * Share init code between quick open and hud
  * Use std::move, fix the clang-tidy warning
  * Use a normal widget for our HUD dialog (kde#500521)
  * Fix documents being stashed during session (kde#497478)
  * Fix Statusbar can't be hidden on git projects (kde#499334)
  * Use editor font in lsp,dap config page (kde#499317)
  * Ensure caption is set when a widget is active (kde#499223)
* Tue Feb  4 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.2/
- Changes since 24.12.1:
  * ensure we always stay in range (kde#498435)
  * ensure the remove action works without selection, too (kde#498268)
  * Allow ignoring QSqlQuery prepare failure (kde#498431)
  * Fix Search MatchExport (kde#499080)
  * Set path for eslint process
* Tue Jan  7 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.1/
- Changes since 24.12.0:
  * snapcraft: Bring in fixes from release/24.08
  * Build plugin: Add the <pre> tag to all lines
* Thu Dec 26 2024 Petr Vanek <petr@yarpen.cz>
- new Qt keychain dependency to re-enable SQL plugin build
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.0/
- Changes since 24.11.90:
  * Make placeholder text translatable
  * Add Kate branding color
* Mon Dec  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.90
  * New feature release
- Changes since 24.11.80:
  * Add back distance check to hide tooltip
  * Fix #496460: Match export not working with lookarounds (kde#496460)
  * don't die if the arrays not only contain integers
  * don't pass a nullptr to ::fromLatin1 (kde#496602)
  * Update typescript-language-server url
  * Avoid ctag indexing the home/root dir
  * fix language ids for javascript derivates (kde#495805)
  * Try to have a PATH on macos when not launched from terminal
  * Build output improvements
  * Build: Append html output
  * try to properly use toLocalFile for local files
  * Skip "Save macro recording" action when recording is going on (kde#494464)
  * Ensure key press/release are sent to the same widget
  * Fix active tab not being set inactive
  * Fix snippet completion execution
  * Fix snippets not working unless completion is hard invoked (kde#495416)
  * Remove useless Qbytearray->QString conversion
* Sat Nov 16 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.80
  * New feature release
- Too many changes to list here.
* Tue Nov  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.3/
- Changes since 24.08.2:
  * Fix sql copy/export is randomly ordered (kde#461419)
  * formatting: Listen to all process signals properly
  * KateViewSpace: Store session group name on save
  * Fix QString.arg calls
  * Add libffi8 needed by opensuse.
  * snapcraft: Fix ld-library-config.
* Tue Oct  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.2/
- Changes since 24.08.1:
  * snapcraft: Add paths for libs in core22 to ld_library_path
  * snapcraft: Ensure $SNAP path is first in LD_LIBRARY_PATH
  * snapcraft: Patchelf dri files so we have graphics.
  * fix strange behavior on document close after restore (kde#487034)
  * add compat code to read old session config for views
  * fix session restore of tabs/views of untitled documents (kde#464703)
  * don't store pointer
* Tue Sep 10 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.1/
- Changes since 24.08.0:
  * snapcraft: Fix typo..
  * snapcraft: Actually add the neon packages.
  * snapcraft: Use neon packages to simplify build and runtime.
  * snapcraft: New upstream release. Refresh prime cleanup.
  * back to normal konsole
  * Remove unneeded search result expanding limit (kde#491890)
  * KateBuildView: Remove close button entirely
  * Formatter: add formatting for Odin language
  * Change the default LSP client for GLSL language to glsl_analyzer
  * Fix tooltip hides on scrolling using scrollbar (kde#492092)
  * Tooltip: Only highlight blocks that are marked BlockCodeLanguage (kde#492076)
  * Dont insert line breaks in tooltip (kde#492062)
  * Fix crash on window close
  * Build release branch.
* Mon Aug 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.0/
- Too many changes since 24.05.2, only listing bugfixes:
  * Fix Show sidebar shortcut not being restored properly (kde#453715)
  * Tabs: Wrap around to first on nextTab if current is last tab (kde#476565)
  * Diff: Allow jumping to hunks with full context (kde#488418)
  * Diff: Forward wheel event to editor (kde#490406)
  * try to avoid to create parent less widgets (kde#490712)
  * fix crash if no konsole installed (kde#490957)
  * Allow removing multiple items from welcome page (kde#490308)
  * plugin_kategdp: When breakpoint mark changes, toggle breakpoint for it (kde#481691)
  * ensure we restore stashed documents with right encoding (kde#489360)
  * use session file name as stash folder name (kde#485551)
  * Fix katesql plugin build (kde#488694)
  * Fix crash in urlbar (kde#489931)
  * keep track of focus for widgets, too (kde#485209)
  * ensure plugin actions are in front of context menu (kde#488336)
  * update clangd homepage (kde#486939)
  * Fix ruby method parsing and nested classes parsing (kde#480756)
  * keep track of recent used files on saveAs & close (kde#486203)
  * use kate from the right virtual desktop (kde#486066)
  * S&R: Improve tab handling (kde#484231)
* Tue Jul  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.2/
- No code change since 24.05.1
* Wed Jun 12 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.1/
- Changes since 24.05.0:
  * guard more dbus headers
  * add missing KWindowSystem include
  * guard fillinRunningKateAppInstances
  * guard dbus header
  * guard dbus app adaptor
* Sun May 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.0/
- Changes since 24.04.80:
  * KateSaveModifiedDialog: Use message box icon size from style
  * UrlBar: Optimize showing a directory
  * UrlBar: Fix filtering in treeview
  * urlbar: Slightly optimize current symbol finding
  * UrlBar: Fix symbol view
  * Fix RBQL toolview remains after plugin is disabled
  * Refer to qml language server binary by upstream name
  * fix capture warnings
  * fix capture warnings
  * use 6.0 as minimal release and use C++20 like frameworks
  * use new theme and style init functions
  * keep track of recent used files on saveAs & close (kde#486203)
  * make dbus optional is a start, needs more work
  * don't force konsole master
  * use kate from the right virtual desktop (kde#486066)
* Fri May  3 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.04.80
  * New feature release
- Too many changes since 24.02.2, only listing bugfixes:
  * Fix external tools get lost on modification (kde#456502)
  * Fix crash on deleting the only file in view (kde#485738)
  * project: Add ruff code analysis tool (kde#466175)
  * Fix tooltip hides on trying to scroll using scrollbar (kde#485120)
  * Documents: Fix sorting for directories (kde#476307)
  * ColorPicker: connect to line wrap/unwrap signals (kde#475109)
  * Add Rainbow CSV plugin (kde#451981)
  * Fix tabbar visibility check (kde#455890)
  * Fix session autosave deletes view session config (kde#482018)
  * Restore last active toolview when closing file history (kde#474129)
  * diag: Fix filtering after removing previous items (kde#481381)
  * move lsp context menu actions to xmlgui (kde#477224)
  * add size limit config option to search in files (kde#480489)
  * don't acces member without checking (kde#482946)
  * improve safefty, don't crash on non arrays (kde#482152)
  * fix crash on close other with active widget (kde#481625)
  * more descriptive label (kde#464065)
  * fix Kate snippets: crash when editing a snippet repository (kde#478230)
  * fix: terminal path automatically changes on launch even if the terminal setting is disabled (kde#480080)
* Tue Apr  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.2/
- Changes since 24.02.1:
  * Add job to publish to Microsoft Store
  * Enable appx build for Windows
  * add appimage ci
  * [CI/CD] Add macOS jobs
  * build Qt6 based Appx
* Tue Apr  2 2024 Christophe Marin <christophe@krop.fr>
- Add a couple recommended plugins to preview files in kate
* Tue Mar 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.1/
- Changes since 24.02.0:
  * Fix tooltip not hiding after context menu was opened
  * diag: Trying to match cursor position instead of just line
  * diag: Match severity when trying to find item for line
  * diag: Fix severity filter
  * diag: Fix relatedInfo and fix items are hidden after applying filter
  * share code for url handling
  * don't acces member without checking (kde#482946)
  * improve safefty, don't crash on non arrays (kde#482152)
  * flatpak: Switch to non-preview runtime
  * Fix rainbow highlighting breaks on bracket removal
  * tabswitcher: Do not emit if we're adding no documents
  * Fix tabswitcher performance when large of docs are opened
  * Avoid many proxy invalidations on close
  * fix crash on close other with active widget (kde#481625)
* Fri Feb 23 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.0
  * New feature release
- Changes since 24.01.95:
  * Fix tabswitcher performance when large of docs are opened
  * Avoid many proxy invalidations on close
  * fix crash on close other with active widget (kde#481625)
  * Fix crash
  * Documents: Fix row numbers not updated after dnd
  * Fix diagnostic count when removing diagnostics from a doc with multiple providers
  * diag: Always allow diagnostics for active document
* Fri Feb  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.01.95
  * https://kde.org/announcements/megarelease/6/rc2/
* Fri Dec 15 2023 Christophe Marin <christophe@krop.fr>
- Require extra-cmake-modules at build time
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.4/
- No code change since 23.08.3
* Tue Nov  7 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.3/
- Changes since 23.08.2:
  * snapcraft: Don't bundle c++ libs. (kde#476498)
  * Reflect move of KActivities out of Frameworks to Plasma
  * Update to reflect move of KUserFeedback to Frameworks
  * snapcraft: Fix wayland installs by bundling qtwayland libs.
  * Fix crash on dropping file in project (kde#476016)
  * snapcraft: add missig build dep gettext.
  * [flatpak] Use Qt5 branch for deps
  * snapcraft: initial import snacraft files
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.2/
- Changes since 23.08.1:
  * ensure we don't crash if no item is selected (kde#475379)
  * Fix prettier.resolveConfig.sync is not a function (kde#474722)
  * Explicitly call QCoreApplication::exit()
* Tue Sep 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.1/
- Changes since 23.08.0:
  * lsp: Fix crash on clicking "Close dynamic reference tabs" (kde#474216)
  * Fix assert when moving a widget to a new vertical viewspace
  * Fix crash on viewspace close
* Sun Aug 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.0/
- Changes since 23.07.90:
  * Fix crash when adding/removing suppression
  * Use QFontMetrics::lineSpacing to calculate the line y offset (kde#473362)
* Mon Aug 14 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.90
  * New feature release
- Changes since 23.07.80:
  * block session auto save in some more places
  * File Browser plugin: make search string partial-matching (kde#472374)
  * Fix diagnostics tab overlay
  * check that blocking level is zero
  * avoid that the session save timer messes up session saving (kde#470293)
  * Add missing $ to fix installed translated documentation
  * Add missing KI18n links
  * handle tab deletion/creation
  * diagnostics: Handle suppressions from multiple providers
  * diagnostics: Refactor diagnostics removal
  * Remove Designer's "." normaloff file data from icon properties in .ui files
  * ensure we don't use m_quickOpen uninited
  * remove deprecated Id
  * ensure proper parent for dialog
  * ensure proper parent for dialog
* Tue Aug  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.80
  * New feature release
- Too many changes since 23.04.3, only listing bugfixes:
  * lsp: always honor server when using Completion.textEdit.newText (kde#468130)
  * Add open action to tabbar context menu (kde#471471)
  * use word-completion-minimal-word-length as configured (kde#470494)
  * Allow opening new tab in front of currently active tab optionally (kde#471225)
  * Fix double drive letters on "Run Current Doc" (kde#469340)
  * ensure sidebars are properly collapsed (kde#460160)
  * Don't ask user if he wants to save modified document when deleting (kde#448861)
  * Fix --version, --help, -h, -v not working (kde#468318)
  * CompilerExplorer: Fix crash when minimizing (kde#468294)
  * Fix preview for markdown files not loaded on mode change (kde#384972)
  * Include markdownpart in flatpak builds (kde#466349)
  * Fix asking to save untitled empty doc on close (kde#462347)
  * Intoduce open links plugin (kde#93087)
  * Konsole: Show error when konsole not found (kde#438308)
  * Intoduce KateTextHintManager (kde#467322)
  * Use internal diff view in KateMWonHDDialog (kde#441120)
  * ensure projects view is focused (kde#465786)
  * Allow opening multiple files from welcome view (kde#467097)
  * Cleanup/improve MWModOnHDDialog (kde#464088)
  * Search: Fix crash on clicking clear (kde#467255)
* Tue Jul  4 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.3/
- Changes since 23.04.2:
  * Improve code action invocation with no selection
  * Fix LSP inlay hint deserialization
  * lsp: Use label as insertText as a last resort
* Tue Jun  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.2/
- Changes since 23.04.1:
  * Fix double drive letters on "Run Current Doc" (kde#469340)
* Tue May  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.1/
- Changes since 23.04.0:
  * ensure sidebars are properly collapsed (kde#460160)
* Sat Apr 15 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.0/
* Fri Mar 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.90
  * New feature release
* Fri Mar 17 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.80
  * New feature release
- Rebase patch:
  * 0001-Defuse-root-block.patch
* Thu Mar 16 2023 Christophe Marin <christophe@krop.fr>
- Use the %%ldconfig_scriptlets macro
* Tue Feb 28 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.3/
* Tue Jan 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.2/
- Drop patch, merged upstream:
  * 0001-Fix-settings-saving-regression-in-CTags-plugin.patch
* Mon Jan  9 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to fix the save button in the ctags configuration
  (kde#463993, boo#1206984):
  * 0001-Fix-settings-saving-regression-in-CTags-plugin.patch
* Tue Jan  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.1/
* Fri Dec  2 2022 Christophe Marin <christophe@krop.fr>
- Update to 22.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.0/
* Sat Nov 26 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.90
  * New feature release
* Sat Nov 12 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.80
  * New feature release
* Tue Nov  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.3/
* Tue Oct 11 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.2/
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.1/
* Sun Aug 14 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.0/
* Fri Aug  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.90
  * New feature release
* Sat Jul 16 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.80
  * New feature release
- Rebase 0001-Defuse-root-block.patch
* Tue Jul  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.3/
* Wed Jun  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.2/
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.1/
* Mon Apr 18 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.0/
* Fri Apr  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.90
  * New feature release
* Wed Mar 23 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.80
  * New feature release
- Too many changes since 21.12.3, only listing bugfixes:
  * show documents as loaded from config (kde#353373)
  * ensure some proper initial size (kde#450686)
  * make config dialog scrollable (kde#445541)
  * Handle SIGINT/SIGTERM to prevent accidental data loss (kde#445016)
  * Fix crash when closing multiple tabs if limited number of tabs is enabled (kde#450873)
  * Sort by url instead of comparing strings (kde#435334)
  * Fix tab jumping with unlimited tabs (kde#440585, kde#435780)
  * Fix LRU tab behaviour (kde#434062)
  * S&R: Fix Look-ahead & behind highlighting & replace (kde#449545)
  * Fix stashing not working when Kate is quit using Ctrl+Q (kde#449229)
  * lspclient: also support some alternative WorkspaceEdit replies (kde#447640)
  * Allow DND of tabs among viewspaces (kde#426768)
  * Dont bring kate to front when files externally modified (kde#353712)
  * Fix the check to also handle 0 doc views (kde#448847)
  * Improve views closing in split view behaviour (kde#344374)
  * Fix terminal focus action text when focusing/defocusing (kde#409813)
  * step down warning level when LSP not found (kde#448549)
  * filetree: Fix folders collapse after opening new file (kde#410143)
  * Clear highlights if text field becomes empty (kde#436674)
  * lspclient: only allow symbol view header toggle sort when applicable (kde#447653)
  * Search: Utilize context lengths more efficiently (kde#438094)
  * Fix search for unsaved files (kde#434287)
  * Ignore rename if newName == oldName (kde#447951)
  * SemanticTokens: Use size_t as argument for type (kde#447553)
  * GDB: Use debug-run theme icon in stead of custom icon (kde#444670)
  * do nothing if use canceled project open (kde#447194)
  * fix sessions segfault because of invalid iterator (kde#446863)
  * enable/disable project actions (kde#445494)
- Use GCC 10 for building kate on Leap 15.
* Tue Mar  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.3/
- Changes since 21.12.2:
  * Fix stashing not working when Kate is quit using Ctrl+Q (kde#449229)
* Tue Feb  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.2/
- Changes since 21.12.1:
  * improve QProcess handling
  * avoid that we execute LSP binaries from cwd (CVE-2022-23853)
  * step down warning level when LSP not found (kde#448549)
  * lspclient: send didSave notification if so requested
  * lspclient: consider some additional server capabilities
* Tue Jan  4 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.1/
- Changes since 21.12.0:
  * lsp: Do not HTML escape markdown text
  * Fix blame not visible after switching to a 'diff view'
  * SemanticTokens: Use size_t as argument for type (kde#447553)
  * lsp: Handle client/RegisterCapability
  * Fix incorrect blame info parsing when summary has '\t'
  * ColorBrackets: Fix disconnecting wrong view
  * Fix 2 second delays for everything semantic highlighting related
  * do nothing if use canceled project open (kde#447194)
  * Ensure to clean up saved ranges when docs close
  * enable/disable project actions (kde#445494)
  * Fix segfault on session change
  * try to fix compile on FreeBSD
  * build 'Colored brackets for readability' plugin in master
  * fix sessions segfault because of invalid iterator (kde#446863)
  * appstream: Remove duplicated release info
  * Fix LSPTooltip sizing
* Fri Dec  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.0/
- Changes since 21.11.90:
  * Fix git blame for git submodules
  * Fix blame fails when opening a single file
  * git-blame: Fix commit summary not available
  * Introducing Colored Brackets plugin
* Sat Nov 27 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.90
  * New feature release
- Changes since 21.11.80:
  * Add more options for clangd
* Sat Nov 13 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.80
  * New feature release
- Too many changes since 21.08.3, only listing bugfixes:
  * LSP Completion: use textEdit.newText as a workaround (kde#445085)
  * Fix compile cpp when path has spaces (kde#443618)
  * Show LspClient after positioning (kde#443895)
  * fixes reload dialog on wayland (kde#440583)
  * avoid crash on session rename (kde#443267)
  * fix view differences (kde#441120)
  * save 'Show output view for message type' setting (kde#442707)
  * Fix infinite recursion in project filter model (kde#443026)
  * Fix replicode plugin not deleting its toolview (kde#441859)
  * Delete unfilled entries in tool config group (kde#437419)
  * KWrite: use KStandardAction::preferences (kde#441505)
  * Escape shortcut mnemonic markers (&) in tab texts (kde#441340)
  * Allow multiple tabs for Konsole plugin(s) (kde#437922, kde#419710, kde#435398, kde#200322, kde#145203)
  * handle nullptr return of screenAt() (kde#439804)
  * Expand tool view sidebars when they are collapsed (kde#439535)
  * avoid that tool view split view collapse (kde#439535)
* Tue Nov  2 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.3/
- No code change since 21.08.2
* Tue Oct  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.2/
- Changes since 21.08.1:
  * Fix replicode plugin not deleting its toolview (kde#441859)
  * Fix commit dialog width
- Change the license tag to LGPL-2.0-only AND LGPL-2.1-or-later.
  There are no GPL-3.0 files.
* Wed Sep  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.1
- Changes since 21.08.0:
  * semantic highlighter: Use a timer to reduce amount of requests being sent
* Fri Aug  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.0
- Changes since 21.07.90:
  * improve kate on haiku os
  * avoid double branch name computation
- Rebase 0001-Defuse-root-block.patch
* Fri Jul 30 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.90
  * New feature release
- Changes since 21.07.80:
  * LocHistory: When limiting size, also rewind currentLocation
  * Location history improvements
  * handle nullptr return of screenAt() (kde#439804)
* Sat Jul 17 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.80
  * New feature release
- Too many changes since 21.04.3, only listing bugfixes:
  * ensure we unify line endings (kde#436753)
  * add missing name for hot new stuff (kde#438018)
  * lspclient: bypass shutdown delay if not needed and cleanup defunct code (kde#438790)
  * ensure to not crash on missing context menu (kde#426939)
  * lspclient: add action to request and apply quick fix code action (kde#437746)
  * Work around conflicting shortcuts in preview plugin (kde#386265)
  * S&R: Fix matching ^ and $ in multi-line expressions (kde#318232)
  * Prevent storing diff files in recent files history (kde#436906)
- Only install the license files once
* Wed Jul  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.3
- Changes since 21.04.2:
  * Make sure we only have one button for 'Enable Indexing'
* Tue Jun  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.2
- Changes since 21.04.1:
  * Prevent crash in git-blame for HUGE git commits (kde#437683)
  * Fix crash when turning on "bg shading" for Documents plugin
  * deactivate Kate command bar if KXMLGui command bar is there
* Wed May 12 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/21.04.1
- Changes since 21.04.0:
  * Fix possible leak when commiting
  * Fix branch change not reflected if projectbase != dotGit
  * git: Don't report error if git not found
  * Fix changing branch doesn't update the branch button
  * Try to fix of a rare crash with Ctrl + Click in LSP
  * show new mascot in about dialog
  * Html escape lsptooltip text
  * Downgrade .git not found warning to info message (kde#435945)
* Fri Apr 16 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04
- Changes since 21.03.90:
  * Fix S&R not recovering from canceled folder search (kde#435689)
- Stop owning directories provided by the filesystem package (boo#1184786)
* Fri Apr  9 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.90
  * New feature release
- Too many changes to list here.
* Sun Mar 21 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.80
  * New feature release
- Too many changes to list here.
- Rebase 0001-Defuse-root-block.patch
* Thu Mar  4 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/20.12.3
- No code change since 20.12.2
* Wed Feb  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-02-apps-update
- No code change since 20.12.1
* Tue Jan  5 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-01-apps-update
- No code change since 20.12.0
* Sat Dec  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-12-apps-update
- No code change since 20.11.90
* Fri Nov 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.90
  * New feature release
- No code change since 20.11.80
* Sat Nov 14 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.80
  * New feature release
- Too many changes since 20.08.3, only listing bugfixes:
  * lspclient: also secretly accept LocationLink in some replies (kde#427270)
  * implement optional limit for number of tabs and LRU replacement (kde#426520)
* Thu Nov  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-11-apps-update
- Changes since 20.08.2:
  * lspclient: only consider user configuration contents changes as change (kde#427084)
  * lspclient: correctly unregister the registered TextHintProvider (kde#427338)
* Fri Oct  9 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-10-apps-update
- Changes since 20.08.1:
  * ensure that even if the url is empty, we create some parent
    to avoid accessing nullptr parent (kde#427270)
  * addons/externaltools: Really respect BUILD_TESTING
  * close tabs again with middle mouse button click (kde#426042)
  * avoid that the KTextEditor::View XMLGUI elements are lost
    after a tab is closed (kde#426605)
* Tue Sep  1 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-09-apps-update
- No code change since 20.08.0
* Sun Aug  9 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-08-apps-update
- No code change since 20.07.90
* Sun Aug  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.07.90
  * New feature release
- Changes since 20.07.80:
  * Highlight documentation: add feature of comment position
  * apply make clang-format
  * cleanup internal handling of tabs
  * Use camelcase includes (scripted)
* Sun Jul 19 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.07.80
  * New feature release
- Too many changes since 20.04.3, only listing bugfixes:
  * register files not only at recently opened files menu but globally, too (kde#420504)
  * Properly port away from deprecated QProcess::start() (kde#420794)
  * Fix crash if search command is used while searching (kde#419719)
* Thu Jul  9 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-07-apps-update
- No code change since 20.04.2
* Tue Jun  9 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-06-apps-update
- No code change since 20.04.1
* Fri May 15 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-05-apps-update
- Changes since 20.04.0:
  * Properly port away from deprecated QProcess::start() (kde#420794)
* Thu Apr 23 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-04-apps-update
- Changes since 20.03.90:
  * Revert premature porting
* Sun Apr  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.90
  * New feature release
- No code change since 20.03.80
* Sun Mar 22 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.80
  * New feature release
- Too many changes since 19.12.3, only listing bugfixes:
  * Fix External Tool "Google Selected Text" (kde#416509)
  * lspclient: avoid repeated restart of failing LSP server (kde#415847)
  * try to fix embedding of icon for windows (kde#415260)
  * document that the version is important for the choice of the syntax definition to load (kde#414997)
  * Open/close and focus/defocus terminal using the same shortcuts as Dolphin (kde#414587)
* Thu Mar  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-03-apps-update
- Changes since 19.12.2:
  * appdata: improve URLs
  * try to add enough large icons for Windows (256/512 px)
* Fri Feb  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Wed Feb  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-02-apps-update
- Too many changes since 19.12.1, only listing bugfixes:
  * only allow the new pass through policy for windows (kde#416078)
  * try to fix embedding of icon for windows (kde#415260)
* Tue Jan  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12.1
- Changes since 19.12.0:
  * Unbreak build with cmake < 3.7 (VERSION_GREATER_EQUAL only avail >= 3.7)
  * Update Appstream for new release
  * Fix crash when pressing ESC after external tools plugin was un/reloaded
  * sort settings file by language id
  * initial support for javascript + typescript LSP
  * lsp: update info of OCaml server
  * lspclient: aid compilation on older version by explicit json object conversion
  * relax ocaml regex
  * allow highlighting mode => language id mapping to be configured in the JSON config
  * Add icons to metadata of plugins supporting KDevelop/Plugin
* Tue Dec 10 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12
- Changes since 19.11.90:
  * Update Appstream for new release
  * Make the strings translatable, fix typo
  * Fix translation of external tools (kde#181528)
  * Fix: Do not translate KActionCollection identifier
* Sat Nov 30 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/19.12-rc
- Changes since 19.11.80:
  * Read the user visible name of the default color scheme
  * Fix tyop in find_package call
  * Respect KF5_MIN_VER and QT_MIN_VER
  * Search for KF5I18n and KF5DocTools
  * Search for Qt5Widgets to make a version comparison work
- Dropped patches, now upstream:
  * search-for-kf5i18n-kdoctools.patch
* Sun Nov 24 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.80
  * New feature release
- Too many changes since 19.08.3, only listing bugfixes:
  * handle build path as relative to project path (kde#413306)
  * disable ctags indexing per default (kde#412351)
  * fix message extraction (kde#412358)
  * External Tools: Support adding actions to toolbar (kde#261210)
  * ensure view stack gets focus on startup (kde#412227)
  * Added a line to set default sort order for the Symbolviewer. (kde#405895)
  * allow ESC to be used as global application shortcut and still exit the quick open (kde#409856)
  * fix dbus session registration (kde#410742)
- Add upstream patch to fix build:
  * search-for-kf5i18n-kdoctools.patch
* Thu Nov  7 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.3.php
- Changes since 19.08.2:
  * ensure outer layout set
  * try to avoid nested layouts that we don't need
* Fri Oct 11 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.2.php
- Changes since 19.08.1:
  * Reasonable sub-toolbar sizes, like normal QPushButton sizes
  * Load terminal on demand to have some parent widget for WINDOWID computation
  * Tab bar: use tab-close icon again
  * Fix hi-dpi rendering of tab buttons
  * Fix hi-dpi rendering of toolview buttons
  * Tab bar: Fix close button in right-to-left layout
  * Fix HiDPI support for KWrite + Kate
  * Fix fortran symbol viewer for new highlighting names
- Refreshed patches:
  * 0001-Defuse-root-block.patch
* Thu Sep  5 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.1.php
- Changes since 19.08.0:
  * fix stop button of search and replace plugin
* Fri Aug  9 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.0.php
- Changes since 19.07.90:
  * Fix dbus session registration (kde#410742)
* Tue Aug  6 2019 lbeltrame@kde.org
- Update to 19.07.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-rc.php
- No code changes since 19.07.80
* Tue Jul 23 2019 lbeltrame@kde.org
- Update to 19.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-beta.php
- Changes since 19.04.3:
  * Too many changes to list here
* Sat Jul 13 2019 lbeltrame@kde.org
- Update to 19.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.3.php
- No code changes since 19.04.2
* Fri Jun  7 2019 lbeltrame@kde.org
- Update to 19.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.2.php
- No code changes since 19.04.1
* Fri May 10 2019 lbeltrame@kde.org
- Update to 19.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.1.php
- Changes since 19.04.0:
  * tabswitcher_test: pass correct binary name to add_test()
  * Use add_test signature where target command gets resolved to binary path
* Sat Apr 20 2019 lbeltrame@kde.org
- Update to 19.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.0.php
- Changes since 19.03.90:
  * improve comment
  * fix handling of sub modules in git rely on ls-files --recurse-submodules, there since end of 2016
* Tue Apr  9 2019 lbeltrame@kde.org
- Update to 19.03.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-rc.php
- Changes since 19.03.80:
  * No code changes since 19.03.80
* Wed Mar 27 2019 lbeltrame@kde.org
- Update to 19.03.80
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-beta.php
- Changes since 18.12.3:
  * Too many changes to list here
- Refreshed patches:
  * 0001-Defuse-root-block.patch
* Sat Mar  9 2019 lbeltrame@kde.org
- Update to 18.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.3.php
- Changes since 18.12.2:
  * No code changes since 18.12.2
* Sat Feb  9 2019 lbeltrame@kde.org
- Update to 18.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.2.php
- Changes since 18.12.1:
  * No code changes since 18.12.1
* Fri Jan 11 2019 lbeltrame@kde.org
- Update to 18.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.1.php
- Changes since 18.12.0:
  * [projectplugin] Correct code index widget show
  * [kateproject tool] Fine tune cppcheck
  * [kateproject] Gracefully exit when analyzer is not finished
  * ViewManager: Fix I18n_ARGUMENT_MISSING hint in message box when open a very large file
* Fri Dec 14 2018 lbeltrame@kde.org
- Update to 18.12.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.0.php
- Changes since 18.11.90:
  * No code changes since 18.11.90
* Wed Dec  5 2018 Jan Engelhardt <jengelh@inai.de>
- Remove ldconfig calls as there are no libraries.
* Mon Dec  3 2018 lbeltrame@kde.org
- Update to 18.11.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-rc.php
- Changes since 18.11.80:
  * No code changes since 18.11.80
* Tue Nov 20 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Tue Nov 20 2018 lbeltrame@kde.org
- Update to 18.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-beta.php
- Changes since 18.08.3:
  * Too many changes to list here
* Thu Nov  8 2018 lbeltrame@kde.org
- Update to 18.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.3.php
- Changes since 18.08.2:
  * Open document before using it's checksum to load metainfos (kde#384087)
* Thu Oct 11 2018 lbeltrame@kde.org
- Update to 18.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.2.php
- Changes since 18.08.1:
  * None
* Thu Sep  6 2018 lbeltrame@kde.org
- Update to 18.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.1.php
- Changes since 18.08.0:
  * Explicitly include <QWidgetAction>
* Thu Aug 16 2018 christophe@krop.fr
- Update to 18.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.0.php
- Changes since 18.07.80:
  * Honor BUILD_TESTING
* Thu Aug  2 2018 fabian@ritter-vogt.de
- Use %%license
- License is actually GPL-3.0-or-later
* Thu Jul 26 2018 lbeltrame@kde.org
- Update to 18.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08-beta.php
- Changes since 18.04.3:
  * Too many changes to list here
- Refreshed patches:
  * 0001-Defuse-root-block.patch
- Drop custom lang package definition
* Fri Jul 13 2018 lbeltrame@kde.org
- Update to 18.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.3.php
- Changes since 18.04.2:
  * Fix if to actually have a comparison
  * Fix QuickOpen with Qt 5.11 (kde#395039)
- Dropped patches, now upstream:
  * 0002-Fix-QuickOpen-with-Qt-5.11.patch
- Refreshed patches:
  * 0001-Defuse-root-block.patch
* Thu Jun 14 2018 marius.kittler@suse.com
- Add 0002-Fix-QuickOpen-with-Qt-5.11.patch for kde#395039
  to make quick-open work again after Qt 5.11.0 update.
* Fri Jun  8 2018 lbeltrame@kde.org
- Update to 18.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.2.php
- Changes since 18.04.1:
  * None
* Fri May 11 2018 lbeltrame@kde.org
- Update to 18.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.1.php
- Changes since 18.04.0:
  * None
* Wed Apr 18 2018 lbeltrame@kde.org
- Update to 18.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.0.php
- Changes since 18.03.90:
  * None
* Fri Apr  6 2018 lbeltrame@kde.org
- Update to 18.03.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04-rc.php
- Changes since 17.12.3:
  * Too many changes to list here
* Thu Mar  8 2018 lbeltrame@kde.org
- Update to 17.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.3.php
- Changes since 17.12.2:
  * None
* Wed Feb  7 2018 lbeltrame@kde.org
- Update to 17.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.2.php
- Changes since 17.12.1:
  * Revert "Clear konsole command-line before directory change"
  * Make connection unique to not trigger flood of slot calls.
  * Fix a couple of regressions in the conversion to modern connect() (kde#388752)
* Thu Jan 11 2018 lbeltrame@kde.org
- Update to 17.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.1.php
- Changes since 17.12.0:
  * Clear konsole command-line before directory change
* Sat Dec  9 2017 lbeltrame@kde.org
- Update to 17.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.0.php
- Changes since 17.11.90:
  * None
* Sat Dec  2 2017 lbeltrame@kde.org
- Update to 17.11.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-rc.php
- Changes since 17.11.80:
  * Fix crash on re-enabling "Document Preview" plugin (kde#387233)
* Mon Nov 20 2017 lbeltrame@kde.org
- Update to 17.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-beta.php
- Changes since 17.08.3:
  * Too many changes to list here
* Thu Nov  9 2017 lbeltrame@kde.org
- Update to 17.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.3.php
- Changes since 17.08.2:
  * None
* Mon Oct 16 2017 lbeltrame@kde.org
- Update to 17.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.2.php
- Changes since 17.08.1:
  * None
* Thu Sep  7 2017 lbeltrame@kde.org
- Update to 17.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.1.php
- Changes since 17.08.0:
  * None
* Fri Aug 11 2017 christophe@krop.fr
- Update to KDE Applications 17.08.0
  * New feature release
  * https://www.kde.org/announcements/announce-applications-17.08.0.php
- Changes since 17.04.3 :
- Too many changes to list here
* Sat Aug  5 2017 christophe@krop.fr
- Update to KDE Applications 17.07.90
  * KDE Applications 17.07.90
  * https://www.kde.org/announcements/announce-applications-17.08-rc.php
* Sat Jul 15 2017 lbeltrame@kde.org
- Update to 17.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.3.php
- Changes since 17.04.2:
  * None
* Wed Jun  7 2017 lbeltrame@kde.org
- Update to 17.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.2.php
- Changes since 17.04.1:
  * None
* Thu May 18 2017 fabian@ritter-vogt.de
- Add patch to defuse root block:
  * 0001-Defuse-root-block.patch
* Wed May 17 2017 lbeltrame@kde.org
- Update to 17.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.1.php
- Changes since 17.04.0:
  * Don't repeat work of KAboutData::setupCommandLine()
  * Don't repeat work of KAboutData::setApplicationData()
  * Enable numericMode for sorting document list in filetree (kde#375676)
- Drop upstreamed patches:
  * enable-numericMode-in-filetree.patch
* Sun Apr 16 2017 wbauer@tmo.at
- Add enable-numericMode-in-filetree.patch to sort the file names
  in the "Documents" pane naturally, i.e. 10 comes after 9
  instead of before (kde#375676)
* Sun Apr 16 2017 lbeltrame@kde.org
- Update to 17.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.0.php
- Changes since 17.03.90:
  * None
* Wed Apr 12 2017 lbeltrame@kde.org
- Update to 17.03.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-rc.php
- Changes since 17.03.80:
  * None
* Thu Mar 30 2017 lbeltrame@kde.org
- Drop upstreamed patch: remove-popupapplet-servicetype.patch
* Sat Mar 25 2017 lbeltrame@kde.org
- Update to 17.03.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-beta.php
- Changes since 16.12.3:
  * Too many changes to list here
* Thu Mar  9 2017 lbeltrame@kde.org
- Update to 16.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-16.12.3.php
- Changes since 16.12.2:
  * Add shortcut (Ctrl+Alt+f) for Search and Replace (kde#368377)
* Thu Feb  9 2017 lbeltrame@kde.org
- Update to KDE Applications 16.12.2
  * KDE Applications 16.12.2
  * https://www.kde.org/announcements/announce-applications-16.12.2.php
* Thu Jan 19 2017 fabian@ritter-vogt.de
- Add upstream patch to fix build with plasma-framework >= 5.30
  * remove-popupapplet-servicetype.patch
* Sat Jan 14 2017 lbeltrame@kde.org
- Update to KDE Applications 16.12.1
  * KDE Applications 16.12.1
  * https://www.kde.org/announcements/announce-applications-16.12.1.php
* Tue Dec 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.12.0
  * KDE Applications 16.12.0
  * https://www.kde.org/announcements/announce-applications-16.12.0.php
* Sat Dec  3 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.90
  * KDE Applications 16.12.0 RC
  * https://www.kde.org/announcements/announce-applications-16.12-rc.php
* Tue Nov 29 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.80
  * KDE Applications 16.12.0 Beta
  * https://www.kde.org/announcements/announce-applications-16.12-beta.php
* Wed Nov  9 2016 wbauer@tmo.at
- Remove unnecessary build requirements
* Wed Nov  9 2016 lbeltrame@kde.org
- Update to KDE Applications 16.08.3
  * KDE Applications 16.08.3
  * https://www.kde.org/announcements/announce-applications-16.08.3.php
* Tue Oct 11 2016 lbeltrame@kde.org
- KDE Applications 16.08.2
  https://www.kde.org/announcements/announce-applications-16.08.2.php
* Mon Oct 10 2016 hrvoje.senjan@gmail.com
- Try to fix build on Leap 42.1 with newer KF5
* Mon Sep 26 2016 toddrme2178@gmail.com
- Update year
- Enable git integration
- Fix building on Leap 42.1
* Fri Sep  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.1
  * KDE Applications 16.08.1
  * https://www.kde.org/announcements/announce-applications-16.08.1.php
* Wed Aug 24 2016 fabian@ritter-vogt.de
- Adjust filelist for the plasmoid appdata, installed with KF > 5.25.0
* Fri Aug 12 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.0
  * KDE Applications 16.08.0
  * https://www.kde.org/announcements/announce-applications-16.08.0.php
* Mon Aug  8 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.07.90
  * KDE Applications 16.07.90 (16.08-RC)
  * https://www.kde.org/announcements/announce-applications-16.08-rc.php
* Thu Jul  7 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.3
  * KDE Applications 16.04.3
  * https://www.kde.org/announcements/announce-applications-16.04.3.php
* Fri Jun 10 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.2
  * KDE Applications 16.04.2
  * https://www.kde.org/announcements/announce-applications-16.04.2.php
* Sat May  7 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.1
  * KDE Applications 16.04.1
  * https://www.kde.org/announcements/announce-applications-16.04.1.php
* Sun Apr 17 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.0
  * KDE Applications 16.04.0
  * https://www.kde.org/announcements/announce-applications-16.04.0.php
* Mon Apr 11 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.03.90
  * KDE Applications 16.04.0 RC
  * https://www.kde.org/announcements/announce-applications-16.04-rc.php
* Sun Mar 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.3
  * KDE Applications 15.12.3
  * https://www.kde.org/announcements/announce-applications-15.12.3.php
  * boo#970855
* Sat Feb 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.2
  * KDE Applications 15.12.2
  * https://www.kde.org/announcements/announce-applications-15.12.2.php
  * boo#966605
* Sun Feb  7 2016 tittiatcoke@gmail.com
- Kwrite does not require kate, so lets not put the kwrite icon in
  the kate package.
* Sat Jan  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.1
  * KDE Applications 15.12.1
  * https://www.kde.org/announcements/announce-applications-15.12.1.php
  * boo#961265
* Sun Dec 13 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.0
  * KDE Applications 15.12.0
  * https://www.kde.org/announcements/announce-applications-15.12.0.php
  * boo#958887
* Tue Nov 10 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.3
  * KDE Applications 15.08.3
  * https://www.kde.org/announcements/announce-applications-15.08.3.php
  * boo#954531
* Sun Oct 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.2
  * KDE Applications 15.08.2
  * https://www.kde.org/announcements/announce-applications-15.08.2.php
* Tue Sep 22 2015 alarrosa@suse.com
- Fixed a "directories not owned by a package" error
* Sun Sep 13 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.1
  * KDE Applications 15.08.1
  * https://www.kde.org/announcements/announce-applications-15.08.1.php
* Wed Aug 19 2015 cgiboudeaux@gmx.com
- Update to KDE Applications 15.08.0
  * KDE Applications 15.08.0
  * https://www.kde.org/announcements/announce-applications-15.08.0.php
* Fri Aug  7 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.07.90
  * KDE Applications 15.08.0 RC1
  * https://www.kde.org/announcements/announce-applications-15.08-rc.php
* Mon Jul  6 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.3
  * KDE Applications 15.04.3
  * https://www.kde.org/announcements/announce-applications-15.04.3.php
* Sat May 30 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.2
  * KDE Applications 15.04.2
  * https://www.kde.org/announcements/announce-applications-15.04.2.php
* Mon May 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.1
  * KDE Applications 15.04.1
  * https://www.kde.org/announcements/announce-applications-15.04.1.php
* Sat Apr 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.0
  * KDE Applications 15.04.0
  * https://www.kde.org/announcements/announce-applications-15.04.0.php
* Sat Mar 21 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.03.95
  * KDE Applications 15.04 RC
* Sun Mar  8 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.03.80
  * KDE Applications 15.04 Beta
* Tue Mar  3 2015 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.3
  * KDE Applications 14.12.3
  * See https://www.kde.org/announcements/announce-applications-14.12.3.php
* Wed Feb 25 2015 hrvoje.senjan@gmail.com
- Added katefix.diff: Register with dbus to wake up KRun, and
  unregister then (kde#339094)
* Sun Feb  1 2015 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.2
  * KDE Applications 14.12.2
  * See https://www.kde.org/announcements/announce-applications-14.12.2.php
* Mon Jan 12 2015 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.1
  * KDE Applications 14.12.1
  * See https://www.kde.org/announcements/announce-applications-14.12.1.php
* Wed Dec 17 2014 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.0
  * KDE Applications 14.12.0
  * See https://www.kde.org/announcements/announce-applications-14.12.0.php
* Wed Dec 17 2014 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.0
  * KDE Applications 14.12.0
  * See https://www.kde.org/announcements/announce-applications-14.12.0.php
* Wed Dec  3 2014 tittiatcoke@gmail.com
  Update to KDE Applications 14.11.97
  * KDE Applications 14.12 Release Candidate
  * See http://www.kde.org/announcements/announce-applications-14.12-rc.php
  * Kate is now KDE Frameworks based
* Sun Nov  9 2014 tittiatcoke@gmail.com
- Update to 4.14.3
  * KDE 4.14.3 SC Bugfix Release
  * See http://www.kde.org/announcements/announce-4.14.3.php
* Sun Oct 12 2014 tittiatcoke@gmail.com
- Update to 4.14.2
  * KDE 4.14.2 SC Bugfix Release
  * See http://www.kde.org/announcements/announce-4.14.2.php
* Sat Sep 13 2014 tittiatcoke@gmail.com
- Update to 4.14.1
  * KDE 4.14.1 SC Bugfix Release
  * See http://www.kde.org/announcements/announce-4.14.1.php
* Fri Sep  5 2014 hrvoje.senjan@gmail.com
- Use suplements: packageand(IPython:kate), instead of recommending
  IPython as that deliver an installation of 4 digit number of packages
* Fri Aug 15 2014 tittiatcoke@gmail.com
- Update to 4.14.0
  * KDE 4.14.0 SC Final Release
  * See http://www.kde.org/announcements/4.14/
* Wed Aug 13 2014 toddrme2178@gmail.com
- Add subpackage for the python plugins
  - Requires additional python requires for full functionality
* Thu Jul 17 2014 cgiboudeaux@gmx.com
- Update to 4.13.90
  * KDE 4.14 Beta 2 release
  * See http://www.kde.org/announcements/announce-4.14-beta2.php
* Thu Jul 10 2014 cgiboudeaux@gmx.com
- Update to 4.13.80
  * KDE 4.14 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.14-beta1.php
* Sun Jul  6 2014 hrvoje.senjan@gmail.com
- Use create_subdir_filelists macro for putting files where they
  belong
- Drop some ancient obsoletes
- Drop fdupes usage: this is dangerous on multiple binary packages
  from one source
* Sun Jun  8 2014 tittiatcoke@gmail.com
- Update to 4.13.2
  * KDE 4.13  release
  * See http://www.kde.org/announcements/announce-4.13.2.php
* Fri May  9 2014 tittiatcoke@gmail.com
- Update to 4.13.1
  * KDE 4.13.1  bug fix release
  * See http://www.kde.org/announcements/announce-4.13.1.php
* Fri Apr 11 2014 tittiatcoke@gmail.com
- Update to 4.13.0
  * KDE 4.13  release
  * See http://www.kde.org/announcements/4.13/
* Thu Mar 27 2014 tittiatcoke@gmail.com
- Update to 4.12.97
  * KDE 4.13 RC  release
  * See http://www.kde.org/announcements/announce-4.13-rc.php
* Thu Mar 20 2014 tittiatcoke@gmail.com
- Update to 4.12.95
  * KDE 4.13 Beta 3  release
  * See http://www.kde.org/announcements/announce-4.13-beta3.php
* Thu Mar 13 2014 tittiatcoke@gmail.com
- Update to 4.12.90
  * KDE 4.13 Beta 2  release
  * See http://www.kde.org/announcements/announce-4.13-beta2.php
* Fri Mar  7 2014 tittiatcoke@gmail.com
- Update to 4.12.80
  * KDE 4.13 Beta 1  release
  * See http://www.kde.org/announcements/announce-4.13-beta1.php
* Sat Feb  1 2014 tittiatcoke@gmail.com
- Update to 4.12.2
  * KDE 4.12.2  release
  * See http://www.kde.org/announcements/announce-4.12.2.php
* Sat Jan 11 2014 tittiatcoke@gmail.com
- Update to 4.12.1
  * KDE 4.12.1  release
  * See http://www.kde.org/announcements/announce-4.12.1.php
* Sat Dec 14 2013 tittiatcoke@gmail.com
- Update to 4.12.0
  * KDE 4.12.0  release
  * See http://www.kde.org/announcements/4.12.php
* Fri Nov 29 2013 tittiatcoke@gmail.com
- Update to 4.11.97
  * KDE 4.12 RC 1 release
  * See http://www.kde.org/announcements/announce-4.12-rc.php
* Sat Nov 23 2013 tittiatcoke@gmail.com
- Update to 4.11.95
  * KDE 4.12 Beta 3 release
  * See http://www.kde.org/announcements/announce-4.12-beta3.php
* Sat Nov 16 2013 tittiatcoke@gmail.com
- Update to 4.11.90
  * KDE 4.12 Beta 2 release
  * See http://www.kde.org/announcements/announce-4.12-beta2.php
* Sat Nov  9 2013 tittiatcoke@gmail.com
- Update to 4.11.80
  * KDE 4.12 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.12-beta1.php
* Sat Nov  2 2013 tittiatcoke@gmail.com
- Update to 4.11.3
  * KDE 4.11.3 bugfix release
  * See http://www.kde.org/announcements/announce-4.11.3.php
* Sat Sep 28 2013 tittiatcoke@gmail.com
- Update to 4.11.2
  * KDE 4.11.2 bugfix release
  * See http://www.kde.org/announcements/announce-4.11.2.php
* Sun Sep  1 2013 tittiatcoke@gmail.com
- Update to 4.11.1
  * KDE 4.11.1 bugfix release
  * See http://www.kde.org/announcements/announce-4.11.1.php
* Thu Aug  8 2013 tittiatcoke@gmail.com
- Update to 4.11.0
  * KDE 4.11 Final release
  * See http://www.kde.org/announcements/4.11/
* Thu Jul 25 2013 hrvoje.senjan@gmail.com
- Update to 4.10.97
  * KDE 4.11 RC 2 release
  * See http://www.kde.org/announcements/announce-4.11-rc2.php
* Mon Jul 15 2013 cgiboudeaux@gmx.com
- Update to 4.10.95
  * KDE 4.11 RC 1 release
  * See http://www.kde.org/announcements/announce-4.11-rc1.php
* Thu Jun 27 2013 tittiatcoke@gmail.com
- Update to 4.10.90
  * KDE 4.11 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.11-beta2.php
* Thu Jun 13 2013 tittiatcoke@gmail.com
- Update to 4.10.80
  * KDE 4.11 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.11-beta1.php
* Sat Jun  1 2013 tittiatcoke@gmail.com
- Update to 4.10.4
  * Bugfix release
  * See http://www.kde.org/announcements/announce-4.10.4.php
  * resolves bnc#8122760
* Sat May  4 2013 tittiatcoke@gmail.com
- Update to 4.10.3
  * Bugfix release
  * See http://www.kde.org/announcements/announce-4.10.3.php
  * resolves bnc#818500
* Mon Apr  1 2013 tittiatcoke@gmail.com
- Update to 4.10.2
  * Bugfixes
- Drop fix-braindead-logic-in-PyQt-version-detection.diff and
  use-a-numeric-comparision.patch, they are included upstream
* Thu Mar 21 2013 hrvoje.senjan@gmail.com
- Added fix-braindead-logic-in-PyQt-version-detection.diff, fixes
  build with PyQT >= 4.10
- Add provides/obsoletes for go-kate in libktexteditor, both packages
  ship the same syntax file
* Wed Mar 13 2013 hrvoje.senjan@gmail.com
- Added use-a-numeric-comparision.patch from upstream, fixes
  building with python-qt 4.10
* Sat Mar  2 2013 tittiatcoke@gmail.com
- Update to 4.10.1
  * Contains bug fixes. See http://www.kde.org/announcements/
  for more information
- Drop fix-plugin-loading.diff, applied upstream
* Mon Feb 11 2013 hrvoje.senjan@gmail.com
- Added upstream fix-plugin-loading.diff, fixes kde#314530
* Thu Jan 31 2013 tittiatcoke@gmail.com
- Update to 4.10.0
  * This is the final release for 4.10. Contains bugfixes
* Thu Jan 17 2013 tittiatcoke@gmail.com
- Update to 4.9.98
  * This is the third RC release for 4.10. Contains bugfixes
* Thu Jan  3 2013 tittiatcoke@gmail.com
- Update to 4.9.97
  * This is the second RC release for 4.10. Contains bugfixes
- Dropped patch fix_build_for_unicode_python.diff as this was
  incorporated upstream
* Wed Dec 19 2012 tittiatcoke@gmail.com
- Update to 4.9.95
  * This is the first RC release for 4.10. Contains bugfixes
- Added fix_build_for_unicode_python.diff patch, fixes 32bit
  compilation
* Sat Dec  1 2012 tittiatcoke@gmail.com
- Update to 4.9.90
  * This is the second Beta release for 4.10. Contains bugfixes
* Sat Nov 24 2012 tittiatcoke@gmail.com
- Update to 4.9.80
  * see http://www.kde.org/announcements/announce-4.10-beta1.php
  * Support for Python plugins
  * Advanced gid(1) plugin using both ID files and etags
  * Built-in quick open (Ctrl+Alt+o)
  * New Project Plugin
  * Improved Scripting Support
* Fri Nov  2 2012 tittiatcoke@gmail.com
- Update to 4.9.3
  * see http://kde.org/announcements/announce-4.9.3.php for details
* Sat Sep 29 2012 tittiatcoke@gmail.com
- Update to 4.9.2
  * see http://kde.org/announcements/announce-4.9.2.php for details
* Wed Sep  5 2012 dmueller@suse.com
- update to 4.9.1
  * see http://kde.org/announcements/4.9.1/ for details
* Mon Jul 30 2012 dmueller@suse.com
- update to 4.8.5
  * see http://kde.org/announcements/changelogs/changelog4_8_4to4_8_5.php for details
* Fri Jun  1 2012 dmueller@suse.com
- update to 4.8.4
  * see http://kde.org/announcements/changelogs/changelog4_8_3to4_8_4.php for details
* Sun Apr 29 2012 dmueller@suse.com
- update to 4.8.3
  * see http://kde.org/announcements/changelogs/changelog4_8_2to4_8_3.php for details
* Sat Mar 31 2012 wstephenson@suse.com
- Add xz to BuildRequires
* Thu Mar 29 2012 dmueller@suse.de
- update to 4.8.2
  * see http://kde.org/announcements/changelogs/changelog4_8_1to4_8_2.php for details
* Fri Mar  2 2012 dmueller@suse.de
- update to 4.8.1
  * see http://kde.org/announcements/changelogs/changelog4_8_0to4_8_1.php for details
* Wed Jan 18 2012 dmueller@suse.de
- update to 4.8.0
  * first stable release of KDE 4.8 (only critical fixes over 4.7.98)
  * see http://kde.org/announcements/4.8/ for details
* Tue Jan 10 2012 dmueller@suse.de
- update to 4.7.98
  * RC2+ milestone release of KDE 4.8
  * see http://kde.org/announcements/4.8/ for details
* Wed Dec  7 2011 coolo@suse.com
- fix license to be in spdx.org format
* Fri Dec  2 2011 dmueller@suse.de
- update to 4.7.4
  * see http://kde.org/announcements/changelogs/changelog4_7_3to4_7_4.php for details
* Wed Nov  2 2011 dmueller@suse.de
- update to 4.7.3
  * see http://kde.org/announcements/changelogs/changelog4_7_2to4_7_3.php for details
* Sun Oct  2 2011 dmueller@suse.de
- update to 4.7.2
  * see http://kde.org/announcements/changelogs/changelog4_7_1to4_7_2.php for details
* Thu Sep  1 2011 dmueller@suse.de
- update to 4.7.1
  * Bugfixes over KDE 4.7.0
  * see http://kde.org/announcements/changelogs/changelog4_7_0to4_7_1.php for details
* Thu Aug 18 2011 toddrme2178@gmail.com
- Split kwrite doc package (fix for RPMLINT warning)
- Removed redundant buildrequires
- Cleaned up spec file formatting
* Mon Aug  8 2011 mlin@suse.com
- Fixed group for devel package (fix for RPMLINT warning)
* Fri Jul 22 2011 dmueller@suse.de
- update to 4.7.0
  * Small fixes over KDE 4.7 RC2
  * see http://kde.org/announcements/4.7 for details
* Sat Jul  9 2011 dmueller@suse.de
- update to 4.6.95
* Tue Jun 28 2011 dmueller@suse.de
- update to 4.6.90
* Fri May 20 2011 dmueller@suse.de
- update to 4.6.80
* Sun May  8 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110508
* Mon May  2 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110502
* Sat Apr 23 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110423
* Wed Apr 20 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110420
* Mon Apr 18 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110418
* Sun Apr 10 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110410
* Sun Apr  3 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110403
* Fri Apr  1 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110401
* Thu Mar 31 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110331
* Wed Mar 30 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110330
* Tue Mar 29 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110329
* Mon Mar 28 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110328
* Mon Mar 28 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110328
* Thu Mar 24 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110324
* Wed Mar 23 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110323
* Mon Mar 21 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110321
* Mon Mar 21 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110321
* Sat Mar 19 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110319
* Fri Mar 18 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110318
* Thu Mar 17 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110317
* Wed Mar 16 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110316
* Tue Mar 15 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110315
* Tue Mar 15 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110315
* Mon Mar 14 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110314
* Sun Mar 13 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110313
* Sat Mar 12 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110312
* Fri Mar 11 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110311
* Fri Mar 11 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110311
* Thu Mar 10 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110310
* Thu Mar 10 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110310
* Wed Mar  9 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110309
* Tue Mar  8 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110308
* Mon Mar  7 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110307
* Sun Mar  6 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110306
* Sat Mar  5 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110305
* Fri Mar  4 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110304
* Fri Mar  4 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110304
* Fri Mar  4 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110304
* Thu Mar  3 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110303
* Thu Mar  3 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110303
* Wed Mar  2 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110302
* Tue Mar  1 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110301
* Mon Feb 28 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110228
* Mon Feb 28 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110228
* Sun Feb 27 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110227
* Sun Feb 27 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110227
* Sat Feb 26 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110226
* Fri Feb 25 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110225
* Thu Feb 24 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110224
* Tue Feb 22 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110222
* Tue Feb 22 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110222
* Sun Feb 20 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110220
* Sat Feb 19 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110219
* Fri Feb 18 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110218
* Thu Feb 17 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110217
* Wed Feb 16 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110217
* Wed Feb 16 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110216
* Tue Feb 15 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110216
* Tue Feb 15 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110215
* Mon Feb 14 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110214
* Sun Feb 13 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110213
* Sat Feb 12 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110212
* Sat Feb 12 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110212
* Thu Feb 10 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110210
* Wed Feb  9 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110209
* Wed Feb  9 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110209
* Mon Feb  7 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110207
* Sun Feb  6 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110206
* Sat Feb  5 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110205
* Fri Feb  4 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110204
* Thu Feb  3 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110203
* Wed Feb  2 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110202
* Tue Feb  1 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110201
* Mon Jan 31 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110131
* Sun Jan 30 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110130
* Sun Jan 30 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110130
* Fri Jan  7 2011 dmueller@suse.de
- update to 4.6.41_20110106
* Sun Dec 19 2010 tittiatcoke@gmail.com
- Update to 4.5.86svn1207757
* Fri Dec 10 2010 dmueller@suse.de
- update to 4.5.86svn1205247
* Wed Dec  1 2010 dmueller@suse.de
- update to 4.5.82svn1202688
* Mon Nov 29 2010 tittiatcoke@gmail.com
- Update to 4.5.81svn1202101
* Fri Nov 19 2010 dmueller@suse.de
- update to 4.5.80
  * KDE 4.6 Beta1
  * no upstream changelog available.
  * KBugBuster was dropped because it was broken and unmaintained
* Thu Nov 11 2010 coolo@novell.com
- fix file list
* Thu Oct 28 2010 dmueller@suse.de
- update to 4.5.3
  * see http://kde.org/announcements/changelogs/changelog4_5_2to4_5_3.php for details
* Thu Sep 30 2010 dmueller@suse.de
- update to 4.5.2
  * see http://kde.org/announcements/changelogs/changelog4_5_1to4_5_2.php for details
* Sun Aug 29 2010 tittiatcoke@gmail.com
- Added additional build requirement for Antlr package. This will
  now allow the build of the po2xml binary (bnc#630625)
* Fri Aug 27 2010 dmueller@suse.de
- update to 4.5.1
  * see http://kde.org/announcements/changelogs/changelog4_5_0to4_5_1.php for details
* Thu Jul 29 2010 dmueller@suse.de
- update to 4.5.0
  * KDE 4.5.0 final (version bump over RC3)
* Fri Jul 23 2010 dmueller@suse.de
- update to 4.4.95
  * KDE 4.5 RC3 (not announced)
  * critical fixes for 4.5.0 release
* Fri Jul 16 2010 dmueller@suse.de
- update to 4.4.93svn1149349
* Wed Jul  7 2010 dmueller@suse.de
- update to 4.4.5
  * bugfixes over 4.4.4
  * see http://kde.org/announcements/changelogs/changelog4_4_4to4_4_5.php for details
* Fri Jun 18 2010 dmueller@suse.de
- update to 4.4.4
  * bugfixes over 4.4.3
  * see http://kde.org/announcements/changelogs/changelog4_4_3to4_4_ 4.php for details
  * for most modules only version number as a change (4_4_BRANCH.diff already contained the diff
* Mon May 17 2010 llunak@novell.com
- update 4_4_BRANCH.diff: various fixes, translation updates
* Thu Apr 29 2010 dmueller@suse.de
- update to 4.4.3
  * bugfixes over 4.4.2
  * see http://kde.org/announcements/changelogs/changelog4_4_2to4_4_3.php for details
* Fri Mar 26 2010 dmueller@suse.de
- update to 4.4.2
  * bugfixes over 4.4.1
  * see http://kde.org/announcements/changelogs/changelog4_4_1to4_4_2.php for details
* Fri Feb 26 2010 dmueller@suse.de
- update to 4.4.1
  * bugfixes over 4.4.0
  * see http://kde.org/announcements/changelogs/changelog4_4_0to4_4_1.php for details
* Thu Feb  4 2010 dmueller@suse.de
- update to 4.4.0
  * Critical bugfixes only over 4.3.98
  * see http://www.kde.org/announcements/4.4/ for general overview
* Sun Jan 31 2010 dmueller@suse.de
- update to 4.3.98
  * see http://www.kde.org/announcements/announce-4.4-rc3.php for details
* Wed Jan 20 2010 dmueller@suse.de
- update to 4.3.95
  * see http://www.kde.org/announcements/announce-4.4-rc2.php for details
* Wed Jan  6 2010 dmueller@suse.de
- update to 4.3.90
  * see http://www.kde.org/announcements/announce-4.4-rc1.php for details
* Fri Dec 18 2009 dmueller@suse.de
- update to 4.3.85
  * see http://www.kde.org/announcements/announce-4.4-beta2.php for details
* Fri Dec  4 2009 dmueller@suse.de
- update to 4.3.80 (KDE 4.4 Beta1):
  * see http://techbase.kde.org/Schedules/KDE4/4.4_Feature_Plan
* Mon Nov  2 2009 dmueller@suse.de
- update to 4.3.3
  * see http://kde.org/announcements/changelogs/changelog4_3_2to4_3_3.php for details
* Thu Sep 24 2009 beineri@opensuse.org
- update 4_3_BRANCH.diff: icon fixes and translation updates
* Fri Aug 28 2009 dmueller@suse.de
- update to 4.3.1
  * see http://kde.org/announcements/changelogs/changelog4_3_0to4_3_1.php for details
* Sun Aug 23 2009 tittiatcoke@gmail.com
- Added a patch to enable build by resolving two
    void-return-in-non-void-function errors
* Thu Aug 20 2009 beineri@opensuse.org
- kompare is no real VCS, don't have Development/ in default install
* Fri Jul 31 2009 llunak@suse.cz
- suggest ctags for kate (bnc#527074)
* Wed Jul 29 2009 dmueller@suse.de
- update to 4.3.0
  * see http://kde.org/announcements/4.3 for details
* Tue Jul 21 2009 dmueller@suse.de
- update to 4.2.98
* Thu Jul  9 2009 dmueller@suse.de
- update to 4.2.96
* Thu Jul  2 2009 beineri@opensuse.org
- make lokalize require python-kde4 (bnc#517869)
* Wed Jun 24 2009 dmueller@suse.de
- update to 4.2.95
* Sat Jun 20 2009 beineri@opensuse.org
- drop kde4- package prefixes
* Wed Jun  3 2009 dmueller@suse.de
- update to 4.2.90
* Wed May 27 2009 dmueller@suse.de
- update to 4.2.88svn973768
* Tue May 19 2009 dmueller@suse.de
- update to 4.2.87svn969966
* Mon May 18 2009 dmueller@suse.de
- update to 4.2.86svn967995
* Thu May 14 2009 dmueller@suse.de
- update to 4.2.85 (KDE 4.3 Beta1)
* Thu Apr 30 2009 dmueller@suse.de
- update to 4.2.3
  * see http://kde.org/announcements/changelogs/changelog4_2_2to4_2_3.php
* Thu Mar 26 2009 dmueller@suse.de
- update to 4.2.2
  * see http://kde.org/announcements/changelogs/changelog4_2_1to4_2_2.php
* Fri Feb 27 2009 dmueller@suse.de
- update to 4.2.1
  * see http://kde.org/announcements/changelogs/changelog4_2_0to4_2_1.php
* Thu Feb 19 2009 dmueller@suse.de
- update branch diff
* Thu Jan 22 2009 dmueller@suse.de
- update to 4.2.0
* Fri Jan 16 2009 dmueller@suse.de
- remove unnecessary patch
* Tue Jan 13 2009 dmueller@suse.de
- update to 4.1.96
* Fri Jan  9 2009 dmueller@suse.de
- update to 4.1.87 (KDE 4.2 Januar snapshot)
* Tue Dec 16 2008 dmueller@suse.de
- libical-devel isalready included by kdepimlibs-devel
* Tue Dec 16 2008 stbinner@suse.de
- versionized split-provides are not supported
* Sat Nov 29 2008 stbinner@suse.de
- fix build after removal of libical copy from kdepimlibs
* Thu Nov 20 2008 stbinner@suse.de
- add SLE provides
* Fri Oct 31 2008 dmueller@suse.de
- update to 4.1.3
  * see http://kde.org/announcements/changelogs/changelog4_1_2to4_1_3.php
* Thu Sep 25 2008 dmueller@suse.de
- update to 4.1.2
  * see http://kde.org/announcements/changelogs/changelog4_1_1to4_1_2.php
* Thu Aug 28 2008 dmueller@suse.de
- update to 4.1.1
  * see http://kde.org/announcements/changelogs/changelog4_1to4_1_1.php
* Wed Aug 13 2008 dmueller@suse.de
- branch diff update
* Wed Jul 23 2008 dmueller@suse.de
- update to 4.1.0
* Fri Jul 18 2008 dmueller@suse.de
- update to 4.0.99
* Fri Jul 11 2008 dmueller@suse.de
- update to 4.0.98
* Thu Jul  3 2008 dmueller@suse.de
- update to 4.0.85
* Mon Jun 30 2008 dmueller@suse.de
- add directory ownerships
* Thu Jun 26 2008 dmueller@suse.de
- update to 4.0.84
* Wed Jun 18 2008 dmueller@suse.de
- update to 4.0.83
* Sat Jun 14 2008 schwab@suse.de
- Use -mminimal-toc on ppc64.
* Tue Jun 10 2008 dmueller@suse.de
- update to 4.0.82
* Mon Jun  9 2008 dmueller@suse.de
- update to 4.0.81
* Thu May  1 2008 dmueller@suse.de
- update to 4.0.4
  * http://www.kde.org/announcements/changelogs/changelog4_0_3to4_0_4.php
* Mon Apr 21 2008 dmueller@suse.de
- branch diff update
  * fix time parsing in cervisia
* Thu Mar 27 2008 dmueller@suse.de
- update to 4.0.3
* Wed Feb 27 2008 dmueller@suse.de
- update to 4.0.2
* Fri Feb 15 2008 dmueller@suse.de
- update 4_0_BRANCH.diff
* Thu Jan 31 2008 dmueller@suse.de
- update to 4.0.1
* Sun Jan 20 2008 stbinner@suse.de
- update KDE_4_0_BRANCH.diff
* Sat Jan  5 2008 dmueller@suse.de
- update to 4.0
* Wed Jan  2 2008 stbinner@suse.de
- update to 3.97.2
* Sun Dec 16 2007 dmueller@suse.de
- update to 3.97.1
* Sat Dec  8 2007 dmueller@suse.de
- update to 3.97.0
* Sat Dec  8 2007 stbinner@suse.de
- fix build
* Tue Dec  4 2007 dmueller@suse.de
- update to 3.96.3
* Wed Nov 28 2007 dmueller@suse.de
- update to 3.96.2
* Wed Nov 21 2007 dmueller@suse.de
- update to 3.96.1
* Wed Nov 14 2007 dmueller@suse.de
- update to 3.96.0
* Wed Nov  7 2007 dmueller@suse.de
- update to 3.95.2
* Thu Nov  1 2007 dmueller@suse.de
- update to 3.95.1
* Wed Oct 31 2007 dmueller@suse.de
- update to KDE 4.0 Beta4
* Sat Oct 20 2007 dmueller@suse.de
- update to 3.94.1
* Thu Oct 11 2007 dmueller@suse.de
- udpate to KDE 4.0 Beta3
* Tue Oct  2 2007 stbinner@suse.de
- update to 3.93.0.svn720133
* Wed Sep 26 2007 stbinner@suse.de
- update to 3.93.0.svn717255
* Thu Sep 13 2007 stbinner@suse.de
- update to 3.93.0.svn712063
* Sat Sep  1 2007 stbinner@suse.de
- update to KDE 4.0 Beta 2
* Thu Aug 23 2007 stbinner@suse.de
- update to 3.92.0.svn703915
* Thu Aug 16 2007 stbinner@suse.de
- update to 3.92.0.svn700768
* Thu Aug  9 2007 stbinner@suse.de
- update to 3.92.0.svn697375
- fix file conflict
* Tue Aug  7 2007 stbinner@suse.de
- fix build after strigi update
* Sun Jul 29 2007 stbinner@suse.de
- update to KDE 4.0 Beta 1
* Thu Jul 12 2007 stbinner@suse.de
- update to 3.91.0.svn685971
* Sat Jun 23 2007 stbinner@suse.de
- update to 3.90.1.svn679147
* Fri Jun  8 2007 stbinner@suse.de
- update to 3.90.1.svn670093
* Fri Jun  1 2007 coolo@suse.de
- simplify spec file by using macros from kde4-filesystem
* Thu May 24 2007 stbinner@suse.de
- initial package in abuild
